==> libaria_2.7.5.2+repack.orig.tar.bz2: libaria-2.7.5.2.orig/tests/stripQuoteTest.cpp <==
/*
MobileRobots Advanced Robotics Interface for Applications (ARIA)
Copyright (C) 2004, 2005 ActivMedia Robotics LLC
Copyright (C) 2006, 2007, 2008, 2009, 2010 MobileRobots Inc.
Copyright (C) 2011, 2012 Adept Technology

     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.

     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

If you wish to redistribute ARIA under different terms, contact 
MobileRobots for information about a commercial version of ARIA at 
robots@mobilerobots.com or 
MobileRobots Inc, 10 Columbia Drive, Amherst, NH 03031; 800-639-9481
*/
#include "Aria.h"

void printIt(const char *printing)
{
  char buffer[512];
  
  if (ArUtil::stripQuotes(buffer, printing, 512))
    printf("Old '%s' New '%s'\n", printing, buffer);
  else
    printf("String '%s' didn't work\n", printing);
}

int main(void)
{
  char buffer[512];
  
  printIt("\"\"");

  printIt("");

  printIt("\"");

  printIt("hi");

  printIt("\"hi\"");

  printIt("boy oh boy is this fun!");

  printIt("\"boy oh boy is this fun!\"");

}

==> libaria_2.8.0+repack.orig.tar.bz2: libaria-2.8.0.orig/tests/stripQuoteTest.cpp <==
/*
Adept MobileRobots Robotics Interface for Applications (ARIA)
Copyright (C) 2004, 2005 ActivMedia Robotics LLC
Copyright (C) 2006, 2007, 2008, 2009, 2010 MobileRobots Inc.
Copyright (C) 2011, 2012, 2013 Adept Technology

     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.

     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

If you wish to redistribute ARIA under different terms, contact 
Adept MobileRobots for information about a commercial version of ARIA at 
robots@mobilerobots.com or 
Adept MobileRobots, 10 Columbia Drive, Amherst, NH 03031; +1-603-881-7960
*/
#include "Aria.h"

void printIt(const char *printing)
{
  char buffer[512];
  
  if (ArUtil::stripQuotes(buffer, printing, 512))
    printf("Old '%s' New '%s'\n", printing, buffer);
  else
    printf("String '%s' didn't work\n", printing);
}

int main(void)
{
  char buffer[512];
  
  printIt("\"\"");

  printIt("");

  printIt("\"");

  printIt("hi");

  printIt("\"hi\"");

  printIt("boy oh boy is this fun!");

  printIt("\"boy oh boy is this fun!\"");

}
